<?php if (!defined('ABSPATH')) { exit; } // Exit if accessed directly
/**
 * Simple_Job_Board_Settings_Upload_File_Extensions Class
 * 
 * This file used to define the settings for the resume extensions. Allowable
 * extensions for resume are doc, docx, rtf, txt, odt.
 *
 * @link        https://wordpress.org/plugins/simple-job-board
 * @since      2.2.3
 * @since      2.4.0    Revised Inputs & Outputs Sanitization & Escaping
 *
 * @package     Simple_Job_Board
 * @subpackage  Simple_Job_Board/admin/settings
 * @author     PressTigers <support@presstigers.com>
 */

class Simple_Job_Board_Settings_Upload_File_Extensions {

    /**
     * Initialize the class and set its properties.
     *
     * @since   2.2.3
     */
    public function __construct() {

        // Filter -> Add Settings Uploaded File Extensions Tab
        add_filter('sjb_settings_tab_menus', array($this, 'sjb_add_settings_tab'), 80);

        // Action -> Add Settings Uploaded File Extensions Section 
        add_action('sjb_settings_tab_section', array($this, 'sjb_add_settings_section'), 80);

        // Action -> Save Settings Uploaded File Extensions Section 
        add_action('sjb_save_setting_sections', array($this, 'sjb_save_settings_section'));
    }

    /**
     * Add Settings Uploaded File Extensions Tab.
     *
     * @since    2.2.3
     * 
     * @param    array  $tabs  Settings Tab
     * @return   array  $tabs  Merge array of Settings Tab with "Upload File Extensions" Tab.
     */
    public function sjb_add_settings_tab($tabs) {        
        $tabs['upload_file_ext'] = esc_html__( 'Upload File Extensions', 'simple-job-board' );
        return $tabs;
    }

    /**
     * Add Settings Uploaded File Extensions Section.
     *
     * @since    2.2.3
     * @since    2.9.5      Changed $required = '' when get_option('job_board_upload_file_ext') is FALSE.
     * @since    2.10.1     Added maximum file size option.
     */
    public function sjb_add_settings_section() {
        
        ?>
        <!-- Upload File Extensions -->
        <div data-id="settings-upload_file_ext" class="sjb-admin-settings tab">
            
            <?php
            /**
             * Action -> Add new section before file upload settings .  
             * 
             * @since 2.2.0 
             */
            do_action('sjb_file_upload_settings_before');
            ?>

            <form method="post" id="upload-file-form">
                <h4 class="first"><?php echo esc_html__('Upload File Size', 'simple-job-board'); ?></h4>
                <div class="sjb-section sjb-file-size-section">
                    <div class="sjb-content sjb-file-size-content">
                        <?php
                        /**
                         * Action -> Add new option at the start of list.  
                         * 
                         * @since 2.10.1
                         */
                        do_action('sjb_file_size_options_start');

                        $job_file_max_size = get_option('job_file_max_size') ? esc_html(get_option('job_file_max_size')) : 2;
                        ?>
                        <div class="sjb-form-group">
                            <div class="col-md-3">
                                <label><?php echo esc_html__('Maximum file size', 'simple-job-board'); ?></label>
                            </div>
                            <div class="col-md-4">
                                <input type="text" class="sjb-numbers-only" title="<?php echo esc_html__('Maximum file size', 'simple-job-board'); ?>" placeholder="<?php echo esc_html__('Enter upload file size...', 'simple-job-board'); ?>" name="job_file_max_size" value="<?php echo esc_attr($job_file_max_size); ?>"/>
                                <br>
                                <small><i><?php echo esc_html__('File size in Megabytes(MB)', 'simple-job-board'); ?></i></small>
                            </div>
                        </div>
                        <?php
                        /**
                         * Action -> Add new option at the end of list.  
                         * 
                         * @since 2.10.1 
                         */
                        do_action('sjb_file_size_options_end');
                        ?>
                    </div>
                </div>
                <h4 class="second"><?php echo esc_html__('Upload File Extensions', 'simple-job-board'); ?></h4>
                <div class="sjb-section sjb-file-extensions">
                    <div class="sjb-content sjb-file-extensions">
                        <?php
                        /**
                         * Action -> Add new extension at the start of list.  
                         * 
                         * @since 2.8.3
                         */
                        do_action('sjb_file_extension_options_start');
                        ?>
                        
                        <div class="sjb-form-group sjb-extensions">
                            <?php
                            if( FALSE !== get_option('job_board_all_extensions_check')){
                                if( 'no' === get_option('job_board_all_extensions_check') ){
                                    if( FALSE !== get_option('job_board_upload_file_ext')){
                                        if(in_array('pdf', get_option('job_board_upload_file_ext'))){
                                            $selected = 'checked';
                                        }
                                        else{
                                            $selected = '';
                                        }
                                    }
                                    else{
                                        $selected = '';
                                    }
                                }
                                else{
                                    $selected = 'checked';
                                }
                            }
                            else{
                                $selected = 'checked';
                            }
                            ?>
                            
                            <input type="checkbox" id="upload_file_ext_pdf" name="file_extensions[]" value="pdf" <?php echo esc_attr($selected); ?>>
                            <input type="hidden" name="upload_file_ext_pdf" value="upload_file_ext_pdf">
                            <label for="upload_file_ext_pdf"><img src="<?php echo esc_url( plugin_dir_url(dirname(dirname(__FILE__))) . 'admin/images/pdf.png' ); ?>"> <span><?php echo esc_html__( 'PDF', 'simple-job-board' ); ?></span> </label>
                        </div>

                        <div class="sjb-form-group sjb-extensions">
                            <?php
                            if( 'no' === get_option('job_board_all_extensions_check') ){
                                if( FALSE !== get_option('job_board_upload_file_ext')){
                                    if(in_array('doc', get_option('job_board_upload_file_ext'))){
                                        $selected = 'checked';
                                    }
                                    else{
                                        $selected = '';
                                    }
                                }
                                else{
                                    $selected = '';
                                }
                            }
                            else{
                                $selected = 'checked';
                            }
                            ?>
                            
                            <input type="checkbox" id="upload_file_ext_doc" name="file_extensions[]" value="doc" <?php echo esc_attr($selected ); ?>>
                            <input type="hidden" name="upload_file_ext_doc" value="upload_file_ext_doc">
                            <label for="upload_file_ext_doc"><img src="<?php echo esc_url(  plugin_dir_url(dirname(dirname(__FILE__))) . 'admin/images/doc.png' ); ?>"> <span><?php echo esc_html__( 'Doc', 'simple-job-board' ); ?></span> </label>
                        </div>

                        <div class="sjb-form-group sjb-extensions">
                            <?php
                            if( 'no' === get_option('job_board_all_extensions_check') ){
                                if( FALSE !== get_option('job_board_upload_file_ext')){
                                    if(in_array('docx', get_option('job_board_upload_file_ext'))){
                                        $selected = 'checked';
                                    }
                                    else{
                                        $selected = '';
                                    }
                                }
                                else{
                                    $selected = '';
                                }
                            }
                            else{
                                $selected = 'checked';
                            }
                            ?>
                            
                            <input type="checkbox" id="upload_file_ext_docx" name="file_extensions[]" value="docx" <?php echo esc_attr($selected ); ?>>
                            <input type="hidden" name="upload_file_ext_docx" value="upload_file_ext_docx">
                            <label for="upload_file_ext_docx"><img src="<?php echo esc_url( plugin_dir_url(dirname(dirname(__FILE__))) . 'admin/images/docx.png'); ?>"> <span><?php echo esc_html__( 'Docx', 'simple-job-board' ); ?></span> </label>
                        </div>

                        <div class="sjb-form-group sjb-extensions">
                            <?php
                            if( 'no' === get_option('job_board_all_extensions_check') ){
                                if( FALSE !== get_option('job_board_upload_file_ext')){
                                    if(in_array('odt', get_option('job_board_upload_file_ext'))){
                                        $selected = 'checked';
                                    }
                                    else{
                                        $selected = '';
                                    }
                                }
                                else{
                                    $selected = '';
                                }
                            }
                            else{
                                $selected = 'checked';
                            }
                            ?>
                            
                            <input type="checkbox" id="upload_file_ext_odt" name="file_extensions[]" value="odt" <?php echo esc_attr($selected ); ?>>
                            <input type="hidden" name="upload_file_ext_odt" value="upload_file_ext_odt">
                            <label for="upload_file_ext_odt"><img src="<?php echo esc_url( plugin_dir_url(dirname(dirname(__FILE__))) . 'admin/images/odt.png' ); ?>"> <span><?php echo esc_html__( 'Odt', 'simple-job-board' ); ?></span> </label>
                        </div>

                        <div class="sjb-form-group sjb-extensions">
                            <?php
                            if( 'no' === get_option('job_board_all_extensions_check') ){
                                if( FALSE !== get_option('job_board_upload_file_ext')){
                                    if(in_array('rtf', get_option('job_board_upload_file_ext'))){
                                        $selected = 'checked';
                                    }
                                    else{
                                        $selected = '';
                                    }
                                }
                                else{
                                    $selected = '';
                                }
                            }
                            else{
                                $selected = 'checked';
                            }
                            ?>
                            
                            <input type="checkbox" id="upload_file_ext_rtf" name="file_extensions[]" value="rtf" <?php echo esc_attr($selected ); ?>>
                            <input type="hidden" name="upload_file_ext_rtf" value="upload_file_ext_rtf">
                            <label for="upload_file_ext_rtf"><img src="<?php echo esc_url( plugin_dir_url(dirname(dirname(__FILE__))) . 'admin/images/rtf.png' ); ?>"> <span><?php echo esc_html__( 'Rtf', 'simple-job-board' ); ?></span> </label>
                        </div>

                        <div class="sjb-form-group sjb-extensions">
                            <?php
                            if( 'no' === get_option('job_board_all_extensions_check') ){
                                if( FALSE !== get_option('job_board_upload_file_ext')){
                                    if(in_array('txt', get_option('job_board_upload_file_ext'))){
                                        $selected = 'checked';
                                    }
                                    else{
                                        $selected = '';
                                    }
                                }
                                else{
                                    $selected = '';
                                }
                            }
                            else{
                                $selected = 'checked';
                            }
                            ?>
                            <input type="checkbox" id="upload_file_ext_txt" name="file_extensions[]" value="txt" <?php echo esc_attr($selected ); ?> >
                            <input type="hidden" name="upload_file_ext_txt" value="upload_file_ext_txt">
                            <label for="upload_file_ext_txt"><img src="<?php echo esc_url( plugin_dir_url(dirname(dirname(__FILE__))) . 'admin/images/txt.png' ); ?>"> <span><?php echo esc_html__( 'Text', 'simple-job-board' ); ?></span></label>
                        </div>
                        <?php
                        /**
                         * Action -> Add new extension at the end of list.  
                         * 
                         * @since 2.2.0 
                         */
                        do_action('sjb_file_extension_options_end');

                        if( FALSE !== get_option('job_board_all_extensions_check')){
                            if( 'no' === get_option('job_board_all_extensions_check') ){
                                $check = '';
                            }
                            else{
                                $check = 'checked';
                            }
                        }
                        else{
                            $check = 'checked';
                        }
                        ?>
                        <div class="sjb-form-group">
                            <input type="checkbox" name="all_file_extensions" id="all-file-ext" value="all extension" <?php echo esc_attr( $check ); ?> />
                            <label for="all-file-ext"><?php echo esc_html__('Enable all Extensions', 'simple-job-board'); ?></label>
                            <input type='hidden' name="empty_file_extensions" value="empty_file_extensions" />
                        </div>
                        <div class="sjb-form-group">                            
                            <i class="fa  fa-info-circle" aria-hidden="true" style="margin-bottom: auto;margin-top: auto; margin-right:5px;"></i> <label>
                                <?php echo esc_html__( 'Security rules have been updated since SJB version 2.4.3.', 'simple-job-board' ); ?>
                            </label>
                        </div>
                        
                        <?php
                        /**
                         * Action -> Add new fields at the end of upload section.  
                         * 
                         * @since 2.2.0 
                         */
                        do_action('sjb_file_upload_settings_end');
                        ?>
                    </div>
                </div>
                <input type="hidden" value="1" name="admin_notices" />
                <input type="hidden" name="settings_file_exts_nonce" value="<?php echo wp_create_nonce('jobpost_file_exts_settings'); ?>" >
                <input type="submit" name="upload_file_form_submit" id="upload-file-form-submit" class="button button-primary" value="<?php echo esc_html__('Save Changes', 'simple-job-board'); ?>" />
            </form>
        </div>
        <?php
    }

    /**
     * Save Settings Upload File Extension Section.
     * 
     * This function is used to save the uploaded file extensions settings. User
     * can set the security of uploaded file by enabling/disabling it's 
     * extension & anti-hotlinking rules.
     *
     * @since    2.2.3
     * @since    2.9.5  Added check to un select all extensoions when non is checked.  
     */
    public function sjb_save_settings_section() {
        
        // Check if nonce is set.
        if ( NULL == filter_input( INPUT_POST, 'settings_file_exts_nonce' ) ) {
            return;
        }
        
        // Verify that the nonce is valid.
        check_admin_referer( 'jobpost_file_exts_settings', 'settings_file_exts_nonce' );

        $file_extensions = filter_input( INPUT_POST, 'file_extensions', FILTER_DEFAULT, FILTER_REQUIRE_ARRAY );
        $empty_file_extensions = filter_input( INPUT_POST, 'empty_file_extensions' );
        $all_file_extensions = filter_input( INPUT_POST, 'all_file_extensions' );
        $files_hotlinking = filter_input( INPUT_POST, 'files_hotlinking' );
        $job_file_max_size = filter_input( INPUT_POST, 'job_file_max_size' );
        
        // Save File size on Form Submission
        if(!empty( $job_file_max_size )){
            update_option('job_file_max_size', $job_file_max_size);
        }
        // Save File Extension on Form Submission
        if(empty( $file_extensions ) && empty( $all_file_extensions ) && !empty( $empty_file_extensions )){
            delete_option('job_board_upload_file_ext');
            update_option('job_board_all_extensions_check', 'no');
        }else if ( !empty( $file_extensions )  || !empty( $empty_file_extensions ) ) {

            // Empty Checkboxes Status
            $file_extension = $anti_hotlinking = 'no';

            // Save Extentions Settigns
            if ( !empty( $file_extensions ) ) {

                // Save Extentions in WP Options || Add Options if not Exist
                ( FALSE !== get_option('job_board_upload_file_ext') ) ? 
                    update_option('job_board_upload_file_ext', array_map( 'sanitize_text_field', $file_extensions ) ) :
                    add_option('job_board_upload_file_ext', array_map( 'sanitize_text_field', $file_extensions ), '', 'no');
            }

            // Enable All File Extensions
            if ( isset( $all_file_extensions ) ) {
                update_option('job_board_all_extensions_check', 'yes');
                $file_extension = 'yes';
            }

            // Enable File Anti-hotlinking Rules
            if ( isset( $files_hotlinking ) ) {
                update_option('job_board_anti_hotlinking', 'yes');
                $anti_hotlinking = 'yes';
                $sjbrObj = new Simple_Job_Board_Rewrite();
                $sjbrObj->job_board_rewrite();
            }

            // Disable File Extensions
            if ( 'no' === $file_extension ) {
                update_option('job_board_all_extensions_check', 'no');
            }

            // Disable Anti-Hotlinking Rules
            if ( 'no' === $anti_hotlinking ) {
                update_option('job_board_anti_hotlinking', 'no');
                $sjbrObj = new Simple_Job_Board_Rewrite();
                $sjbrObj->job_board_rewrite();
            }
        }
    }

}
